==============================================
toasty: Creating TOAST tile pyramids in Python
==============================================

The ``toasty`` package helps you create `TOAST
<https://arxiv.org/abs/1812.03926>`_ tile pyramids that can be used in
software such as the `AAS <https://aas.org>`_ `WorldWide Telescope
<http://worldwidetelescope.org/home>`_.

User guide
==========

.. toctree::
   :maxdepth: 1

   api


Getting help
============

If you run into any issues when using ``toasty``, please open an issue `on its
GitHub repository <https://github.com/WorldWideTelescope/toasty/issues>`_.


Acknowledgments
===============

Work on ``toasty`` is funded through the American Astronomical Society
(`AAS`_) `WorldWide Telescope`_ project. The first version of ``toasty`` was
written by Chris Beaumont.
